@@ -2,8 +2,17 @@
 #
 
 errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
-        etype="error", method="eigen", quiet=NULL, zero.policy=NULL,
+        Durbin, etype, method="eigen", quiet=NULL, zero.policy=NULL,
         interval=NULL, tol.solve=1.0e-10, trs=NULL, control=list()) {
+#    .Deprecated("spatialreg::errorsarlm", msg="Function errorsarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      if (!missing(weights)) stop("run spatialreg::errorsarlm directly")
+#      return(spatialreg::errorsarlm(formula=formula, data=data,listw=listw, na.action=na.action, Durbin=Durbin, etype=etype, method=method, quiet=quiet, zero.policy=zero.policy, interval=interval, tol.solve=tol.solve, trs=trs, control=control))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
         timings <- list()
         .ptime_start <- proc.time()
         con <- list(tol.opt=.Machine$double.eps^0.5, returnHcov=TRUE,
@@ -46,7 +55,17 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
 	    subset <- !(1:length(listw$neighbours) %in% na.act)
 	    listw <- subset(listw, subset, zero.policy=zero.policy)
 	}
-
+        if (missing(etype))etype <- "error"
+        if (etype == "Durbin") etype <- "emixed"
+        if (missing(Durbin)) Durbin <- ifelse(etype == "error", FALSE, TRUE)
+        if (listw$style != "W" && is.formula(Durbin)) {
+            Durbin <- TRUE
+            warning("formula Durbin requires row-standardised weights; set TRUE")
+        }
+        if (is.logical(Durbin) && isTRUE(Durbin)) etype <- "emixed"
+        if (is.formula(Durbin)) etype <- "emixed"
+        if (is.logical(Durbin) && !isTRUE(Durbin)) etype <- "error"
+        
 	switch(etype, error = if (!quiet)
                 cat("\nSpatial autoregressive error model\n"),
 	    emixed = if (!quiet)
@@ -81,9 +100,43 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
             fdHess <- NULL
         }
         stopifnot(is.logical(con$fdHess))
-	if (etype == "emixed") {
-                WX <- create_WX(x, listw, zero.policy=zero.policy,
-                    prefix="lag")
+	if (is.formula(Durbin) || isTRUE(Durbin)) {
+                prefix <- "lag"
+                if (isTRUE(Durbin)) {
+                    WX <- create_WX(x, listw, zero.policy=zero.policy,
+                        prefix=prefix)
+                } else {
+	            dmf <- lm(Durbin, data, na.action=na.action, 
+		        method="model.frame")
+                    fx <- try(model.matrix(Durbin, dmf), silent=TRUE)
+                    if (inherits(fx, "try-error")) 
+                        stop("Durbin variable mis-match")
+                    WX <- create_WX(fx, listw, zero.policy=zero.policy,
+                        prefix=prefix)
+                    inds <- match(substring(colnames(WX), 5,
+	                nchar(colnames(WX))), colnames(x))
+                    if (anyNA(inds)) stop("WX variables not in X: ",
+                        paste(substring(colnames(WX), 5,
+                        nchar(colnames(WX)))[is.na(inds)], collapse=" "))
+                    icept <- grep("(Intercept)", colnames(x))
+                    iicept <- length(icept) > 0L
+                    if (iicept) {
+                        xn <- colnames(x)[-1]
+                    } else {
+                        xn <- colnames(x)
+                    }
+                    wxn <- substring(colnames(WX), nchar(prefix)+2,
+                        nchar(colnames(WX)))
+                    zero_fill <- NULL
+                    if (length((which(!(xn %in% wxn)))) > 0L) 
+                        zero_fill <- length(xn) + (which(!(xn %in% wxn)))
+                }
+                dvars <- c(NCOL(x), NCOL(WX))
+                if (is.formula(Durbin)) {
+                    attr(dvars, "f") <- Durbin
+                    attr(dvars, "inds") <- inds
+                    attr(dvars, "zero_fill") <- zero_fill
+                }
 		x <- cbind(x, WX)
 		m <- NCOL(x)
 		rm(WX)
@@ -94,8 +147,17 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
 	cn <- names(aliased)
 	names(aliased) <- substr(cn, 2, nchar(cn))
 	if (any(aliased)) {
-		nacoef <- which(aliased)
-		x <- x[,-nacoef]
+          if (is.formula(Durbin)) {
+	    stop("Aliased variables found: ",
+                paste(names(aliased)[aliased], collapse=" "))
+          } else {
+	    warning("Aliased variables found: ",
+                paste(names(aliased)[aliased], collapse=" "))
+	    nacoef <- which(aliased)
+	    x <- x[,-nacoef]
+	    m <- NCOL(x)
+	    xxcolnames <- colnames(x)
+          }
 	}
 #
         sw <- sqrt(weights)
@@ -196,6 +258,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
         sum_lm_target <- summary.lm(lm.target, correlation = FALSE)
         emixedImps <- NULL
 	if (etype == "emixed") {
+          if (isTRUE(Durbin)) {
             odd <- (m%/%2) > 0
             if (odd) {
                 m2 <- (m-1)/2
@@ -228,8 +291,53 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
                 }
             }
             totImps <- as.matrix(estimable(lm.target, cm)[, 1:2, drop=FALSE])
-            emixedImps <- list(dirImps=dirImps, indirImps=indirImps,
-                totImps=totImps)
+          } else if (is.formula(Durbin)) {
+#FIXME
+              m <- sum(dvars)
+              m2 <- dvars[2]
+              cm <- matrix(0, ncol=m, nrow=m2)
+              for (i in 1:m2) {
+                  cm[i, c(inds[i], i+dvars[1])] <- 1
+              }
+              rownames(cm) <- wxn
+              dirImps <- sum_lm_target$coefficients[2:dvars[1], 1:2,
+                drop=FALSE]
+              rownames(dirImps) <- xn
+              indirImps <- sum_lm_target$coefficients[(dvars[1]+1):m, 1:2,
+                drop=FALSE]
+              if (!is.null(zero_fill)) {
+                if (length(zero_fill) > 0L) {
+                 lres <- vector(mode="list", length=2L)
+                 for (j in 1:2) {
+                  jindirImps <- rep(as.numeric(NA), (dvars[1]-1))
+                  for (i in seq(along=inds)) {
+                    jindirImps[(inds[i]-1)] <- indirImps[i, j]
+                  }
+                  lres[[j]] <- jindirImps
+                 }
+                 indirImps <- do.call("cbind", lres)
+                }
+              }
+              rownames(indirImps) <- xn
+              totImps <- as.matrix(estimable(lm.target, cm)[, 1:2,
+                drop=FALSE])
+              if (!is.null(zero_fill)) {
+                if (length(zero_fill) > 0L) {
+                 lres <- vector(mode="list", length=2L)
+                 for (j in 1:2) {
+                  jtotImps <- dirImps[, j]
+                  for (i in seq(along=inds)) {
+                    jtotImps[(inds[i]-1)] <- totImps[i, j]
+                  }
+                  lres[[j]] <- jtotImps
+                 }
+                 totImps <- do.call("cbind", lres)
+                }
+              }
+              rownames(totImps) <- xn
+          } else stop("undefined emixed state")
+          emixedImps <- list(dirImps=dirImps, indirImps=indirImps,
+              totImps=totImps)
         }
         Vs <- sum_lm_target$cov.unscaled
         tarX <- model.matrix(lm.target)
@@ -277,7 +385,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
 #		asyvar[3:(p+2),3:(p+2)] <- crossprod(xl)
 		asyvar[3:(p+2),3:(p+2)] <- crossprod(xl)/s2
 		asyvar1 <- try(solve(asyvar, tol=tol.solve), silent=TRUE)
-                if (class(asyvar1) == "try-error") {
+                if (inherits(asyvar1, "try-error")) {
                     timings[["eigen_se"]] <- proc.time() - .ptime_start
                     .ptime_start <- proc.time()
                     con$fdHess <- TRUE
@@ -349,7 +457,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
             }
             nm <- paste(method, "fdHess", sep="_")
             timings[[nm]] <- proc.time() - .ptime_start
-        }
+        } else fdHess <- FALSE
 	call <- match.call()
         if (method=="SE_classic") {
             iC <- get("intern_classic", envir=env)
@@ -386,7 +494,9 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
 		ret$na.action <- na.act
 	ret
 }
+#}
 
+#if (FALSE) {
 sar_error_sse <- function(lambda, env) {
     if (get("compiled_sse", envir=env)) {
         ft <- get("first_time", envir=env)
@@ -417,8 +527,18 @@ sar.error.f <- function(lambda, env) {
     assign("f_calls", get("f_calls", envir=env)+1L, envir=env)
     ret
 }
+#}
 
-lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, zero.policy=NULL) {
+lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, Durbin=TRUE, zero.policy=NULL) {
+#    .Deprecated("spatialreg::lmSLX", msg="Function lmSLX moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      if (!is.null(weights)) stop("Use spatialreg::lmSLX() directly")
+#      return(spatialreg::lmSLX(formula=formula, data = data, listw=listw, na.action=na.action, Durbin=Durbin, zero.policy=zero.policy))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
         if (is.null(zero.policy))
             zero.policy <- get("zeroPolicy", envir = .spdepOptions)
         stopifnot(is.logical(zero.policy))
@@ -456,9 +576,45 @@ lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, zero.p
         if (is.null(weights)) weights <- rep(as.numeric(1), n)
         if (any(is.na(weights))) stop("NAs in weights")
         if (any(weights < 0)) stop("negative weights")
-
-        WX <- create_WX(x, listw, zero.policy=zero.policy, prefix="lag")
-        x <- cbind(x, WX)
+        dvars <- c(NCOL(x), 0L)
+        prefix <- "lag"
+        if (isTRUE(Durbin)) {
+            WX <- create_WX(x, listw, zero.policy=zero.policy,
+               prefix=prefix)
+        } else if (is.formula(Durbin)) {
+	    dmf <- lm(Durbin, data, na.action=na.action, 
+	         method="model.frame")
+            fx <- try(model.matrix(Durbin, dmf), silent=TRUE)
+            if (inherits(fx, "try-error"))
+                 stop("Durbin variable mis-match")
+            WX <- create_WX(fx, listw, zero.policy=zero.policy,
+                prefix=prefix)
+            inds <- match(substring(colnames(WX), 5,
+	        nchar(colnames(WX))), colnames(x))
+            if (anyNA(inds)) stop("WX variables not in X: ",
+                paste(substring(colnames(WX), 5,
+                nchar(colnames(WX)))[is.na(inds)], collapse=" "))
+            icept <- grep("(Intercept)", colnames(x))
+            iicept <- length(icept) > 0L
+            if (iicept) {
+                xn <- colnames(x)[-1]
+            } else {
+                xn <- colnames(x)
+            }
+            wxn <- substring(colnames(WX), nchar(prefix)+2,
+                nchar(colnames(WX)))
+            zero_fill <- length(xn) + (which(!(xn %in% wxn)))
+        } else stop("Durbin argument neither TRUE nor formula")
+        dvars <- c(NCOL(x), NCOL(WX))
+        if (is.formula(Durbin)) {
+            attr(dvars, "f") <- Durbin
+            attr(dvars, "inds") <- inds
+            attr(dvars, "zero_fill") <- zero_fill
+        }
+	x <- cbind(x, WX)
+	rm(WX)
+#        WX <- create_WX(x, listw, zero.policy=zero.policy, prefix="lag")
+#        x <- cbind(x, WX)
 # 180128 Mark L. Burkey summary.lm error for SLX object
         colnames(x) <- make.names(colnames(x))
         if (attr(mt, "intercept") == 1L) {
@@ -470,23 +626,24 @@ lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, zero.p
         mixedImps <- NULL
 	K <- ifelse(isTRUE(grep("Intercept",
             names(coefficients(lm.model))[1]) == 1L), 2, 1)
-        m <- length(coefficients(lm.model))
-        odd <- (m%/%2) > 0
-        if (odd) {
-            m2 <- (m-1)/2
-        } else {
-            m2 <- m/2
-        }
-        if (K == 1 && odd) {
+        if (isTRUE(Durbin)) {
+          m <- length(coefficients(lm.model))
+          odd <- (m%/%2) > 0
+          if (odd) {
+              m2 <- (m-1)/2
+          } else {
+              m2 <- m/2
+          }
+          if (K == 1 && odd) {
             warning("model configuration issue: no total impacts")
-        } else {
+          } else {
             cm <- matrix(0, ncol=m, nrow=m2)
             if (K == 2) {
                 if (odd) {
                     rownames(cm) <- nclt[2:(m2+1)]
                 } else {
                     rownames(cm) <- nclt[1:m2]
-                 }
+                }
                 for (i in 1:m2) cm[i, c(i+1, i+(m2+1))] <- 1
 # drop bug fix 2016-09-21 Philipp Hunziker
                 dirImps <- sum_lm_model$coefficients[2:(m2+1), 1:2, drop=FALSE]
@@ -502,16 +659,72 @@ lmSLX <- function(formula, data = list(), listw, na.action, weights=NULL, zero.p
                 rownames(indirImps) <- rownames(cm)
             }
             totImps <- as.matrix(estimable(lm.model, cm)[, 1:2, drop=FALSE])
-            mixedImps <- list(dirImps=dirImps, indirImps=indirImps,
-                totImps=totImps)
-        }
+          } 
+      } else if (is.formula(Durbin)) {
+#FIXME
+            m <- sum(dvars)
+            m2 <- dvars[2]
+            cm <- matrix(0, ncol=m, nrow=m2)
+            for (i in 1:m2) {
+                cm[i, c(inds[i], i+dvars[1])] <- 1
+            }
+            rownames(cm) <- wxn
+            dirImps <- sum_lm_model$coefficients[2:dvars[1], 1:2,
+              drop=FALSE]
+            rownames(dirImps) <- xn
+            indirImps <- sum_lm_model$coefficients[(dvars[1]+1):m, 1:2,
+              drop=FALSE]
+            if (!is.null(zero_fill)) {
+              if (length(zero_fill) > 0L) {
+               lres <- vector(mode="list", length=2L)
+               for (j in 1:2) {
+                 jindirImps <- rep(as.numeric(NA), (dvars[1]-1))
+                   for (i in seq(along=inds)) {
+                     jindirImps[(inds[i]-1)] <- indirImps[i, j]
+                   }
+                     lres[[j]] <- jindirImps
+                   }
+                   indirImps <- do.call("cbind", lres)
+                 }
+               }
+               rownames(indirImps) <- xn
+               totImps <- as.matrix(estimable(lm.model, cm)[, 1:2,
+                 drop=FALSE])
+               if (!is.null(zero_fill)) {
+                 if (length(zero_fill) > 0L) {
+                   lres <- vector(mode="list", length=2L)
+                   for (j in 1:2) {
+                     jtotImps <- dirImps[, j]
+                     for (i in seq(along=inds)) {
+                       jtotImps[(inds[i]-1)] <- totImps[i, j]
+                     }
+                     lres[[j]] <- jtotImps
+                   }
+                   totImps <- do.call("cbind", lres)
+                  }
+                }
+                rownames(totImps) <- xn
+        } else stop("undefined Durbin state")
+        mixedImps <- list(dirImps=dirImps, indirImps=indirImps,
+            totImps=totImps)
+        
         attr(lm.model, "mixedImps") <- mixedImps
+        attr(lm.model, "dvars") <- dvars
         class(lm.model) <- c("SLX", class(lm.model))
         lm.model
 }
+#}
 
 
 predict.SLX <- function(object, newdata, listw, zero.policy=NULL, ...) {
+#    warning("Method predict.SLX moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      return(predict(object=object, newdata=newdata, listw=listw, zero.policy=zero.policy, ...))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
     if (is.null(zero.policy))
         zero.policy <- get("zeroPolicy", envir = .spdepOptions)
     stopifnot(is.logical(zero.policy))
@@ -537,8 +750,17 @@ predict.SLX <- function(object, newdata, listw, zero.policy=NULL, ...) {
     names(res) <- row.names(newdata)
     res
 }
+#}
 
 create_WX <- function(x, listw, zero.policy=NULL, prefix="") {
+#    .Deprecated("spatialreg::create_WX", msg="Function create_WX moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      return(spatialreg::create_WX(x=x, listw=listw, zero.policy=zero.policy, prefix=prefix))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
         if (is.null(zero.policy))
             zero.policy <- get("zeroPolicy", envir = .spdepOptions)
         stopifnot(is.logical(zero.policy))
@@ -580,4 +802,5 @@ create_WX <- function(x, listw, zero.policy=NULL, prefix="") {
         colnames(WX) <- Wvars
         WX
 }
+#}
 
