@@ -19,7 +19,7 @@ nb2listw <- function(neighbours, glist=NULL, style="W", zero.policy=NULL)
 		glist <- vector(mode="list", length=n)
 		for (i in 1:n)
 			if(cardnb[i] > 0) {
-				glist[[i]] <- rep(1, length=cardnb[i])
+				glist[[i]] <- rep(1, cardnb[i])
 				mode(glist[[i]]) <- "numeric"
 			}
 		attr(vlist, "mode") <- "binary"
@@ -111,6 +111,14 @@ nb2listw <- function(neighbours, glist=NULL, style="W", zero.policy=NULL)
 }
 
 can.be.simmed <- function(listw) {
+    .Deprecated("spatialreg::can.be.simmed", msg="Function can.be.simmed moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+    return(spatialreg::can.be.simmed(listw=listw))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	res <- is.symmetric.nb(listw$neighbours, FALSE)
 	if (res) {
 		if (attr(listw$weights, "mode") == "general")
@@ -118,92 +126,18 @@ can.be.simmed <- function(listw) {
 	} else return(res)
 	res
 }
-
-similar.listw_Matrix <- function(listw) {
-	nbsym <- attr(listw$neighbours, "sym")
-	if(is.null(nbsym)) nbsym <- is.symmetric.nb(listw$neighbours, FALSE)
-	if (!nbsym) 
-		stop("Only symmetric nb can yield similar to symmetric weights")
-	if (attr(listw$weights, "mode") == "general")
-		if (!attr(listw$weights, "glistsym"))
-			stop("General weights must be symmetric")
-	n <- length(listw$neighbours)
-	if (n < 1) stop("non-positive number of entities")
-	ww <- as(as_dgRMatrix_listw(listw), "CsparseMatrix")
-	if (listw$style == "W") {
-		d <- attr(listw$weights, "comp")$d
-		d1 <- 1/(sqrt(d))
-		dd <- as(as(Diagonal(x=d), "symmetricMatrix"), "CsparseMatrix")
-		dd1 <- as(as(Diagonal(x=d1), "symmetricMatrix"),
-		    "CsparseMatrix")
-		ww1 <- dd %*% ww
-		res <- dd1 %*% ww1 %*% dd1
-	} else if (listw$style == "S") {
-		q <- attr(listw$weights, "comp")$q
-		Q <- attr(listw$weights, "comp")$Q
-		eff.n <- attr(listw$weights, "comp")$eff.n
-		q1 <- 1/(sqrt(q))
-		qq <- as(as(Diagonal(x=q), "symmetricMatrix"), "CsparseMatrix")
-		qq1 <- as(as(Diagonal(x=q1), "symmetricMatrix"),
-		    "CsparseMatrix")
-		ww0 <- (Q/eff.n) * ww
-		ww1 <- qq %*% ww0
-		sim0 <- qq1 %*% ww1 %*% qq1
-		res <- (eff.n/Q) * sim0
-	} else stop("Conversion not suitable for this weights style")
-	res
-}
-
-
-similar.listw_spam <- function(listw) {
-    if (requireNamespace("spam", quietly = TRUE)) {
-#        if (!require(spam)) stop("spam not available")
-	nbsym <- attr(listw$neighbours, "sym")
-	if(is.null(nbsym)) nbsym <- is.symmetric.nb(listw$neighbours, FALSE)
-	if (!nbsym) 
-		stop("Only symmetric nb can yield similar to symmetric weights")
-	if (attr(listw$weights, "mode") == "general")
-		if (!attr(listw$weights, "glistsym"))
-			stop("General weights must be symmetric")
-	n <- length(listw$neighbours)
-	if (n < 1) stop("non-positive number of entities")
-	sww <- as.spam.listw(listw)
-	if (listw$style == "W") {
-		sd <- attr(listw$weights, "comp")$d
-		sd1 <- 1/(sqrt(sd))
-                if (any(!is.finite(sd1))) {
-                    sd1[!is.finite(sd1)] <- 0
-                    warning("non-finite inverse diagonal values set to zero")
-                }
-		sdd <- spam::diag.spam(sd, n, n)
-		sdd1 <- spam::diag.spam(sd1, n, n)
-		sww1 <- sdd %*% sww
-		res <- sdd1 %*% sww1 %*% sdd1
-	} else if (listw$style == "S") {
-		q <- attr(listw$weights, "comp")$q
-		Q <- attr(listw$weights, "comp")$Q
-		eff.n <- attr(listw$weights, "comp")$eff.n
-		q1 <- 1/(sqrt(q))
-                if (any(!is.finite(q1))) {
-                    sd1[!is.finite(q1)] <- 0
-                    warning("non-finite inverse diagonal values set to zero")
-                }
-		qq <- spam::diag.spam(q, n, n)
-		qq1 <- spam::diag.spam(q1, n, n)
-		ww0 <- (Q/eff.n) * sww
-		ww1 <- qq %*% ww0
-		sim0 <- qq1 %*% ww1 %*% qq1
-		res <- (eff.n/Q) * sim0
-	} else stop("Conversion not suitable for this weights style")
-	return(res)
-    } else {
-        stop("spam not available")
-    }
-}
-
+#}
 
 
 similar.listw <- function(listw) {
+    .Deprecated("spatialreg::similar.listw", msg="Function similar.listw moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::similar.listw(listw=listw))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	nbsym <- attr(listw$neighbours, "sym")
 	if(is.null(nbsym)) nbsym <- is.symmetric.nb(listw$neighbours, FALSE)
 	if (!nbsym) 
@@ -271,6 +205,7 @@ similar.listw <- function(listw) {
 	}
 	res
 }
+#}
 
 #This code converts a "nb" object into a list of three elements 
 #(adj, weights, num) in the format required by WinBUGS
@@ -302,7 +237,7 @@ listw2WB <- function(listw)
 }
 
 minmax.listw <- function(listw) {
-    W <- as(as_dgRMatrix_listw(listw), "CsparseMatrix")
+    W <- as(listw, "CsparseMatrix")
     rm <- max(rowSums(W))
     cm <- max(colSums(W))
     res <- min(c(rm, cm))
