@@ -3,6 +3,14 @@ sacsarlm <- function(formula, data = list(), listw, listw2=NULL, na.action,
 	Durbin, type, method="eigen", quiet=NULL, zero.policy=NULL, 
 	tol.solve=1.0e-10, llprof=NULL, interval1=NULL, interval2=NULL,
         trs1=NULL, trs2=NULL, control=list()) {
+#    .Deprecated("spatialreg::sacsarlm", msg="Function sacsarlm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+#    if (requireNamespace("spatialreg", quietly=TRUE)) {
+#      return(spatialreg::sacsarlm(formula=formula, data=data,listw=listw,listw2=listw2, na.action=na.action, Durbin=Durbin, type=type, method=method, quiet=quiet, zero.policy=zero.policy, tol.solve=tol.solve, llprof=llprof, interval1=interval1, interval2=interval2, trs1=trs1, trs2=trs2, control=control))
+#    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
         timings <- list()
         .ptime_start <- proc.time()
         con <- list(fdHess=NULL, #LAPACK=FALSE,
@@ -73,7 +81,6 @@ sacsarlm <- function(formula, data = list(), listw, listw2=NULL, na.action,
 	n <- NROW(x)
 	m <- NCOL(x)
         dvars <- c(m, 0L)
-#	if (type != "sac") {
 	if (is.formula(Durbin) || isTRUE(Durbin)) {
                 prefix <- "lag"
                 if (isTRUE(Durbin)) {
@@ -83,7 +90,7 @@ sacsarlm <- function(formula, data = list(), listw, listw2=NULL, na.action,
 	            dmf <- lm(Durbin, data, na.action=na.action, 
 		        method="model.frame")
                     fx <- try(model.matrix(Durbin, dmf), silent=TRUE)
-                    if (class(fx) == "try-error") 
+                    if (inherits(fx, "try-error")) 
                         stop("Durbin variable mis-match")
                     WX <- create_WX(fx, listw, zero.policy=zero.policy,
                         prefix=prefix)
@@ -124,8 +131,15 @@ sacsarlm <- function(formula, data = list(), listw, listw2=NULL, na.action,
 	cn <- names(aliased)
 	names(aliased) <- substr(cn, 2, nchar(cn))
 	if (any(aliased)) {
-		nacoef <- which(aliased)
+          if (is.formula(Durbin)) {
+	    stop("Aliased variables found: ",
+                paste(names(aliased)[aliased], collapse=" "))
+          } else {
+	    warning("Aliased variables found: ",
+                paste(names(aliased)[aliased], collapse=" "))
+	    nacoef <- which(aliased)
 		x <- x[,-nacoef]
+          }
 	}
         LL_null_lm <- NULL
 	if ("(Intercept)" %in% colnames(x)) LL_null_lm <- logLik(lm(y ~ 1))
@@ -328,7 +342,7 @@ sacsarlm <- function(formula, data = list(), listw, listw2=NULL, na.action,
             asyvar[3, 2] <- term1 + term2
             asyvar[2, 3] <- asyvar[3, 2]
             asyvar1 <- try(solve(asyvar, tol.solve=tol.solve), silent=TRUE)
-            if (class(asyvar1) == "try-error") {
+            if (inherits(asyvar1, "try-error")) {
                 timings[["eigen_se"]] <- proc.time() - .ptime_start
                 .ptime_start <- proc.time()
                 con$fdHess <- TRUE
@@ -362,7 +376,7 @@ sacsarlm <- function(formula, data = list(), listw, listw2=NULL, na.action,
             }
             nm <- paste(method, "fdHess", sep="_")
             timings[[nm]] <- proc.time() - .ptime_start
-        }
+        } else fdHess <- FALSE
 	call <- match.call()
 	names(r) <- names(y)
 	names(fit) <- names(y)
@@ -393,8 +407,9 @@ sacsarlm <- function(formula, data = list(), listw, listw2=NULL, na.action,
 	ret
 
 }
+#}
 
-
+#if (FALSE) {
 sacsar_sse <- function(coefs, env) {
     rho <- coefs[1]
     lambda <- coefs[2]
@@ -461,5 +476,5 @@ f_sac_hess <- function(coefs, env) {
     if (!is.finite(ret)) return(-Inf)
    ret
 }
-
+#}
 
